# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['starlette_admin',
 'starlette_admin.contrib',
 'starlette_admin.contrib.mongoengine',
 'starlette_admin.contrib.sqla']

package_data = \
{'': ['*'],
 'starlette_admin': ['statics/css/*',
                     'statics/css/img/*',
                     'statics/js/*',
                     'statics/webfonts/*',
                     'templates/*',
                     'templates/displays/*',
                     'templates/displays/js/*',
                     'templates/dt/*',
                     'templates/dt/render/*',
                     'templates/forms/*',
                     'templates/forms/js/*',
                     'templates/macros/*',
                     'templates/modals/*']}

install_requires = \
['Jinja2', 'python-multipart', 'starlette']

setup_kwargs = {
    'name': 'starlette-admin',
    'version': '0.0.1',
    'description': 'Simple and extensible admin interface framework for Starlette/FastApi',
    'long_description': '# starlette-admin\n\n*Starlette-Admin* is a simple and extensible admin interface framework for Starlette/FastApi.\n\nThe key features are:\n\n* **Flexibility :** The biggest feature of *Starlette-Admin* is flexibility. Start with autogenerated CRUD-views of your\n  model and customize those views & forms as the need arises.\n* **Datatables :** *Starlette-Admin* use [Datatables](https://datatables.net/) to render list. Main Features included\n  are:\n    * **Multi-column ordering:** Sort data by multiple columns at once.\n    * **Full-text search:** Filter results by text search with highlight.\n    * **Search Builder:** Filter results by complex query including `AND` and `OR` conditions.\n    * **Many Export options:** Export your data to CSV, PDF, Excel and Browser Print.\n    * You can easily include any other features you need from datatables.\n      Read [Datatables documentation](https://datatables.net/) for more information.\n* **Files Handling :** Easily attach files to your model. Thanks\n  to [SQLAlchemy-file](https://github.com/jowilf/sqlalchemy-file) for SQLAlchemy integration\n* **Multiple admin :** Expose multiple admin interfaces.\n* **Modern UI** using [Tabler](https://tabler.io/)\n\nThis project is inspired by *Flask-Admin* and the main goal is to provide similar tool for Starlette/FastApi.\n\n*Starlette-Admin* can be easily used with any ORM but have currently built-in support for:\n\n* [SQLAlchemy](https://www.sqlalchemy.org/)\n* [SQLModel](https://sqlmodel.tiangolo.com/)\n* [MongoEngine](http://mongoengine.org/)\n\n---\n\n\n**Documentation**: [https://jowilf.github.io/starlette-admin](https://jowilf.github.io/starlette-admin/)\n\n**Source Code**: [https://github.com/jowilf/starlette-admin](https://github.com/jowilf/starlette-admin)\n\n**Online Demo**: [Demo](https://github.com/jowilf)\n\n---\n\n## Installation\n\n### PIP\n\n```shell\n$ pip install starlette-admin\n```\n\n### Poetry\n\n```shell\n$ poetry add starlette-admin\n```\n\n## Example\n\nSQLAlchemy integration\n```Python\nfrom sqlalchemy import Column, Integer, String, create_engine\nfrom sqlalchemy.ext.declarative import declarative_base\nfrom starlette.applications import Starlette\nfrom starlette_admin.contrib.sqla import Admin, ModelView\n\nBase = declarative_base()\nengine = create_engine(\n    "sqlite:///example.db", connect_args={"check_same_thread": False}\n)\n\n\nclass Post(Base):\n    __tablename__ = "posts"\n\n    id = Column(Integer, primary_key=True)\n    title = Column(String)\n\n\nclass PostAdmin(ModelView, model=Post):\n    pass\n\n\nBase.metadata.create_all(engine)\napp = Starlette()\n\nadmin = Admin(engine)\nadmin.add_view(PostAdmin)\nadmin.mount_to(app)\n```\n\nMongoEngine integration\n```Python\nimport mongoengine\nfrom mongoengine import connect\nfrom starlette.applications import Starlette\nfrom starlette_admin.contrib.mongoengine import Admin, ModelView\n\nconnect("example")\n\n\nclass Post(mongoengine.Document):\n    title = mongoengine.StringField(min_length=3, required=True)\n\n\nclass PostAdmin(ModelView, document=Post):\n    pass\n\n\napp = Starlette()\n\nadmin = Admin()\nadmin.add_view(PostAdmin)\nadmin.mount_to(app)\n```\nNow visiting `/admin` on your browser you can see the Admin interface.\n',
    'author': 'Jocelin Hounon',
    'author_email': 'hounonj@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://jowilf.github.io/starlette-admin',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
